﻿using System;

namespace SpreadsheetLight
{
    internal class SLConstants
    {
        internal const string ApplicationName = "SpreadsheetLight";

        internal const string BlankSpreadsheetFileName = "Book1.xlsx";
        internal const string DefaultFirstSheetName = "Sheet1";
        internal const int RowLimit = 1048576;
        internal const int ColumnLimit = 16384;

        internal const string W3CDTF = "yyyy-MM-ddTHH:mm:ssZ";

        // default form is [version][build]
        // Excel 2007 version is 12. Don't know where 5725 came from.
        // We'll just use this (came from author's Office 2007 Small Business edition).
        internal const uint CalculationId = 125725;

        internal const string ErrorDivisionByZero = "#DIV/0!";
        internal const string ErrorNA = "#N/A";
        internal const string ErrorName = "#NAME?";
        internal const string ErrorNull = "#NULL!";
        internal const string ErrorNumber = "#NUM!";
        internal const string ErrorReference = "#REF!";
        internal const string ErrorValue = "#VALUE!";

        internal const int DegreeToAngleRepresentation = 60000;
        internal const long PointToEMU = 12700;
        internal const long InchToEMU = 914400;
        internal const long CentimeterToEMU = 360000;

        internal const int CustomNumberFormatIdStartIndex = 164;
        internal const string NumberFormatGeneral = "General";
        // this is for Excel 2007
        //internal const string DefaultTableStyle = "TableStyleMedium9";
        // this is for Excel 2010
        internal const string DefaultTableStyle = "TableStyleMedium2";
        internal const string DefaultPivotStyle = "PivotStyleLight16";

        // it seems that as long as different numbers are used within a chart,
        // it is fine. And no I don't know how Excel gets those axis IDs...
        internal const int PrimaryAxis1 = 1;
        internal const int PrimaryAxis2 = 2;
        internal const int PrimaryAxis3 = 3;
        internal const int SecondaryAxis1 = 4;
        internal const int SecondaryAxis2 = 5;

        // values are intentionally weird to avoid conflict
        internal const string XmlStyleAttributeSeparator = "(S,}";
        internal const string XmlStyleElementAttributeSeparator = "(S|}";
        internal const string XmlAlignmentAttributeSeparator = "(A,}";
        internal const string XmlProtectionAttributeSeparator = "(P,}";
        internal const string XmlBorderAttributeSeparator = "(B,}";
        internal const string XmlBorderElementAttributeSeparator = "(B|}";
        internal const string XmlBorderPropertiesAttributeSeparator = "(BP,}";
        internal const string XmlBorderPropertiesElementAttributeSeparator = "(BP|}";
        internal const string XmlCellStyleAttributeSeparator = "(CS,}";
        internal const string XmlColorAttributeSeparator = "(CLR,}";
        internal const string XmlPatternFillAttributeSeparator = "(PFi,}";
        internal const string XmlPatternFillElementAttributeSeparator = "(PFi|}";
        internal const string XmlGradientFillAttributeSeparator = "(GFi,}";
        internal const string XmlGradientFillElementAttributeSeparator = "(GFi|}";
        internal const string XmlTableStyleAttributeSeparator = "(TS,}";
        internal const string XmlTableStyleElementAttributeSeparator = "(TS|}";

        internal const double NormalTopMargin = 0.75;
        internal const double NormalBottomMargin = 0.75;
        internal const double NormalLeftMargin = 0.7;
        internal const double NormalRightMargin = 0.7;
        internal const double NormalHeaderMargin = 0.3;
        internal const double NormalFooterMargin = 0.3;

        internal const double WideTopMargin = 1;
        internal const double WideBottomMargin = 1;
        internal const double WideLeftMargin = 1;
        internal const double WideRightMargin = 1;
        internal const double WideHeaderMargin = 0.5;
        internal const double WideFooterMargin = 0.5;

        internal const double NarrowTopMargin = 0.75;
        internal const double NarrowBottomMargin = 0.75;
        internal const double NarrowLeftMargin = 0.25;
        internal const double NarrowRightMargin = 0.25;
        internal const double NarrowHeaderMargin = 0.3;
        internal const double NarrowFooterMargin = 0.3;

        internal const double DefaultFontSize = 11;
        internal const double TitleFontSize = 18;
        internal const double Heading1FontSize = 15;
        internal const double Heading2FontSize = 13;

        // these were obtained from Excel for 120 DPI Calibri 11 pt
        internal const double DefaultCommentBoxWidth = 100.8;
        internal const double DefaultCommentBoxHeight = 60.6;

        internal const double DefaultCommentTopOffset = -0.42;
        internal const double DefaultCommentLeftOffset = 0.1725;

        internal const string OfficeThemeName = "SpreadsheetLight Office";
        internal const string OfficeThemeMajorLatinFont = "Cambria";
        internal const string OfficeThemeMinorLatinFont = "Calibri";
        internal const string OfficeThemeDark1Color = "000000";
        internal const string OfficeThemeLight1Color = "FFFFFF";
        internal const string OfficeThemeDark2Color = "1F497D";
        internal const string OfficeThemeLight2Color = "EEECE1";
        internal const string OfficeThemeAccent1Color = "4F81BD";
        internal const string OfficeThemeAccent2Color = "C0504D";
        internal const string OfficeThemeAccent3Color = "9BBB59";
        internal const string OfficeThemeAccent4Color = "8064A2";
        internal const string OfficeThemeAccent5Color = "4BACC6";
        internal const string OfficeThemeAccent6Color = "F79646";
        internal const string OfficeThemeHyperlink = "0000FF";
        internal const string OfficeThemeFollowedHyperlinkColor = "800080";

        internal const string AdjacencyThemeName = "SpreadsheetLight Adjacency";
        internal const string AdjacencyThemeMajorLatinFont = "Cambria";
        internal const string AdjacencyThemeMinorLatinFont = "Calibri";
        internal const string AdjacencyThemeDark1Color = "2F2B20";
        internal const string AdjacencyThemeLight1Color = "FFFFFF";
        internal const string AdjacencyThemeDark2Color = "675E47";
        internal const string AdjacencyThemeLight2Color = "DFDCB7";
        internal const string AdjacencyThemeAccent1Color = "A9A57C";
        internal const string AdjacencyThemeAccent2Color = "9CBEBD";
        internal const string AdjacencyThemeAccent3Color = "D2CB6C";
        internal const string AdjacencyThemeAccent4Color = "95A39D";
        internal const string AdjacencyThemeAccent5Color = "C89F5D";
        internal const string AdjacencyThemeAccent6Color = "B1A089";
        internal const string AdjacencyThemeHyperlink = "D25814";
        internal const string AdjacencyThemeFollowedHyperlinkColor = "849A0A";

        internal const string AnglesThemeName = "SpreadsheetLight Angles";
        internal const string AnglesThemeMajorLatinFont = "Franklin Gothic Medium";
        internal const string AnglesThemeMinorLatinFont = "Franklin Gothic Book";
        internal const string AnglesThemeDark1Color = "000000";
        internal const string AnglesThemeLight1Color = "FFFFFF";
        internal const string AnglesThemeDark2Color = "434342";
        internal const string AnglesThemeLight2Color = "CDD7D9";
        internal const string AnglesThemeAccent1Color = "797B7E";
        internal const string AnglesThemeAccent2Color = "F96A1B";
        internal const string AnglesThemeAccent3Color = "08A1D9";
        internal const string AnglesThemeAccent4Color = "7C984A";
        internal const string AnglesThemeAccent5Color = "C2AD8D";
        internal const string AnglesThemeAccent6Color = "506E94";
        internal const string AnglesThemeHyperlink = "5F5F5F";
        internal const string AnglesThemeFollowedHyperlinkColor = "969696";

        internal const string ApexThemeName = "SpreadsheetLight Apex";
        internal const string ApexThemeMajorLatinFont = "Lucida Sans";
        internal const string ApexThemeMinorLatinFont = "Book Antiqua";
        internal const string ApexThemeDark1Color = "000000";
        internal const string ApexThemeLight1Color = "FFFFFF";
        internal const string ApexThemeDark2Color = "69676D";
        internal const string ApexThemeLight2Color = "C9C2D1";
        internal const string ApexThemeAccent1Color = "CEB966";
        internal const string ApexThemeAccent2Color = "9CB084";
        internal const string ApexThemeAccent3Color = "6BB1C9";
        internal const string ApexThemeAccent4Color = "6585CF";
        internal const string ApexThemeAccent5Color = "7E6BC9";
        internal const string ApexThemeAccent6Color = "A379BB";
        internal const string ApexThemeHyperlink = "410082";
        internal const string ApexThemeFollowedHyperlinkColor = "932968";

        internal const string ApothecaryThemeName = "SpreadsheetLight Apothecary";
        internal const string ApothecaryThemeMajorLatinFont = "Book Antiqua";
        internal const string ApothecaryThemeMinorLatinFont = "Century Gothic";
        internal const string ApothecaryThemeDark1Color = "000000";
        internal const string ApothecaryThemeLight1Color = "FFFFFF";
        internal const string ApothecaryThemeDark2Color = "564B3C";
        internal const string ApothecaryThemeLight2Color = "ECEDD1";
        internal const string ApothecaryThemeAccent1Color = "93A299";
        internal const string ApothecaryThemeAccent2Color = "CF543F";
        internal const string ApothecaryThemeAccent3Color = "B5AE53";
        internal const string ApothecaryThemeAccent4Color = "848058";
        internal const string ApothecaryThemeAccent5Color = "E8B54D";
        internal const string ApothecaryThemeAccent6Color = "786C71";
        internal const string ApothecaryThemeHyperlink = "CCCC00";
        internal const string ApothecaryThemeFollowedHyperlinkColor = "B2B2B2";

        internal const string AspectThemeName = "SpreadsheetLight Aspect";
        internal const string AspectThemeMajorLatinFont = "Verdana";
        internal const string AspectThemeMinorLatinFont = "Verdana";
        internal const string AspectThemeDark1Color = "000000";
        internal const string AspectThemeLight1Color = "FFFFFF";
        internal const string AspectThemeDark2Color = "323232";
        internal const string AspectThemeLight2Color = "E3DED1";
        internal const string AspectThemeAccent1Color = "F07F09";
        internal const string AspectThemeAccent2Color = "9F2936";
        internal const string AspectThemeAccent3Color = "1B587C";
        internal const string AspectThemeAccent4Color = "4E8542";
        internal const string AspectThemeAccent5Color = "604878";
        internal const string AspectThemeAccent6Color = "C19859";
        internal const string AspectThemeHyperlink = "6B9F25";
        internal const string AspectThemeFollowedHyperlinkColor = "B26B02";

        internal const string AustinThemeName = "SpreadsheetLight Austin";
        internal const string AustinThemeMajorLatinFont = "Century Gothic";
        internal const string AustinThemeMinorLatinFont = "Century Gothic";
        internal const string AustinThemeDark1Color = "000000";
        internal const string AustinThemeLight1Color = "FFFFFF";
        internal const string AustinThemeDark2Color = "3E3D2D";
        internal const string AustinThemeLight2Color = "CAF278";
        internal const string AustinThemeAccent1Color = "94C600";
        internal const string AustinThemeAccent2Color = "71685A";
        internal const string AustinThemeAccent3Color = "FF6700";
        internal const string AustinThemeAccent4Color = "909465";
        internal const string AustinThemeAccent5Color = "956B43";
        internal const string AustinThemeAccent6Color = "FEA022";
        internal const string AustinThemeHyperlink = "E68200";
        internal const string AustinThemeFollowedHyperlinkColor = "FFA94A";

        internal const string BlackTieThemeName = "SpreadsheetLight BlackTie";
        internal const string BlackTieThemeMajorLatinFont = "Garamond";
        internal const string BlackTieThemeMinorLatinFont = "Garamond";
        internal const string BlackTieThemeDark1Color = "000000";
        internal const string BlackTieThemeLight1Color = "FFFFFF";
        internal const string BlackTieThemeDark2Color = "46464A";
        internal const string BlackTieThemeLight2Color = "E3DCCF";
        internal const string BlackTieThemeAccent1Color = "6F6F74";
        internal const string BlackTieThemeAccent2Color = "A7B789";
        internal const string BlackTieThemeAccent3Color = "BEAE98";
        internal const string BlackTieThemeAccent4Color = "92A9B9";
        internal const string BlackTieThemeAccent5Color = "9C8265";
        internal const string BlackTieThemeAccent6Color = "8D6974";
        internal const string BlackTieThemeHyperlink = "67AABF";
        internal const string BlackTieThemeFollowedHyperlinkColor = "B1B5AB";

        internal const string CivicThemeName = "SpreadsheetLight Civic";
        internal const string CivicThemeMajorLatinFont = "Georgia";
        internal const string CivicThemeMinorLatinFont = "Georgia";
        internal const string CivicThemeDark1Color = "000000";
        internal const string CivicThemeLight1Color = "FFFFFF";
        internal const string CivicThemeDark2Color = "646B86";
        internal const string CivicThemeLight2Color = "C5D1D7";
        internal const string CivicThemeAccent1Color = "D16349";
        internal const string CivicThemeAccent2Color = "CCB400";
        internal const string CivicThemeAccent3Color = "8CADAE";
        internal const string CivicThemeAccent4Color = "8C7B70";
        internal const string CivicThemeAccent5Color = "8FB08C";
        internal const string CivicThemeAccent6Color = "D19049";
        internal const string CivicThemeHyperlink = "00A3D6";
        internal const string CivicThemeFollowedHyperlinkColor = "694F07";

        internal const string ClarityThemeName = "SpreadsheetLight Clarity";
        internal const string ClarityThemeMajorLatinFont = "Arial";
        internal const string ClarityThemeMinorLatinFont = "Arial";
        internal const string ClarityThemeDark1Color = "292934";
        internal const string ClarityThemeLight1Color = "FFFFFF";
        internal const string ClarityThemeDark2Color = "D2533C";
        internal const string ClarityThemeLight2Color = "F3F2DC";
        internal const string ClarityThemeAccent1Color = "93A299";
        internal const string ClarityThemeAccent2Color = "AD8F67";
        internal const string ClarityThemeAccent3Color = "726056";
        internal const string ClarityThemeAccent4Color = "4C5A6A";
        internal const string ClarityThemeAccent5Color = "808DA0";
        internal const string ClarityThemeAccent6Color = "79463D";
        internal const string ClarityThemeHyperlink = "0000FF";
        internal const string ClarityThemeFollowedHyperlinkColor = "800080";

        internal const string CompositeThemeName = "SpreadsheetLight Composite";
        internal const string CompositeThemeMajorLatinFont = "Calibri";
        internal const string CompositeThemeMinorLatinFont = "Calibri";
        internal const string CompositeThemeDark1Color = "000000";
        internal const string CompositeThemeLight1Color = "FFFFFF";
        internal const string CompositeThemeDark2Color = "5B6973";
        internal const string CompositeThemeLight2Color = "E7ECED";
        internal const string CompositeThemeAccent1Color = "98C723";
        internal const string CompositeThemeAccent2Color = "59B0B9";
        internal const string CompositeThemeAccent3Color = "DEAE00";
        internal const string CompositeThemeAccent4Color = "B77BB4";
        internal const string CompositeThemeAccent5Color = "E0773C";
        internal const string CompositeThemeAccent6Color = "A98D63";
        internal const string CompositeThemeHyperlink = "26CBEC";
        internal const string CompositeThemeFollowedHyperlinkColor = "598C8C";

        internal const string ConcourseThemeName = "SpreadsheetLight Concourse";
        internal const string ConcourseThemeMajorLatinFont = "Lucida Sans Unicode";
        internal const string ConcourseThemeMinorLatinFont = "Lucida Sans Unicode";
        internal const string ConcourseThemeDark1Color = "000000";
        internal const string ConcourseThemeLight1Color = "FFFFFF";
        internal const string ConcourseThemeDark2Color = "464646";
        internal const string ConcourseThemeLight2Color = "DEF5FA";
        internal const string ConcourseThemeAccent1Color = "2DA2BF";
        internal const string ConcourseThemeAccent2Color = "DA1F28";
        internal const string ConcourseThemeAccent3Color = "EB641B";
        internal const string ConcourseThemeAccent4Color = "39639D";
        internal const string ConcourseThemeAccent5Color = "474B78";
        internal const string ConcourseThemeAccent6Color = "7D3C4A";
        internal const string ConcourseThemeHyperlink = "FF8119";
        internal const string ConcourseThemeFollowedHyperlinkColor = "44B9E8";

        internal const string CoutureThemeName = "SpreadsheetLight Couture";
        internal const string CoutureThemeMajorLatinFont = "Garamond";
        internal const string CoutureThemeMinorLatinFont = "Garamond";
        internal const string CoutureThemeDark1Color = "000000";
        internal const string CoutureThemeLight1Color = "FFFFFF";
        internal const string CoutureThemeDark2Color = "37302A";
        internal const string CoutureThemeLight2Color = "D0CCB9";
        internal const string CoutureThemeAccent1Color = "9E8E5C";
        internal const string CoutureThemeAccent2Color = "A09781";
        internal const string CoutureThemeAccent3Color = "85776D";
        internal const string CoutureThemeAccent4Color = "AEAFA9";
        internal const string CoutureThemeAccent5Color = "8D878B";
        internal const string CoutureThemeAccent6Color = "6B6149";
        internal const string CoutureThemeHyperlink = "B6A272";
        internal const string CoutureThemeFollowedHyperlinkColor = "8A784F";

        internal const string ElementalThemeName = "SpreadsheetLight Elemental";
        internal const string ElementalThemeMajorLatinFont = "Palatino Linotype";
        internal const string ElementalThemeMinorLatinFont = "Palatino Linotype";
        internal const string ElementalThemeDark1Color = "000000";
        internal const string ElementalThemeLight1Color = "FFFFFF";
        internal const string ElementalThemeDark2Color = "242852";
        internal const string ElementalThemeLight2Color = "ACCBF9";
        internal const string ElementalThemeAccent1Color = "629DD1";
        internal const string ElementalThemeAccent2Color = "297FD5";
        internal const string ElementalThemeAccent3Color = "7F8FA9";
        internal const string ElementalThemeAccent4Color = "4A66AC";
        internal const string ElementalThemeAccent5Color = "5AA2AE";
        internal const string ElementalThemeAccent6Color = "9D90A0";
        internal const string ElementalThemeHyperlink = "9454C3";
        internal const string ElementalThemeFollowedHyperlinkColor = "3EBBF0";

        internal const string EquityThemeName = "SpreadsheetLight Equity";
        internal const string EquityThemeMajorLatinFont = "Franklin Gothic Book";
        internal const string EquityThemeMinorLatinFont = "Perpetua";
        internal const string EquityThemeDark1Color = "000000";
        internal const string EquityThemeLight1Color = "FFFFFF";
        internal const string EquityThemeDark2Color = "696464";
        internal const string EquityThemeLight2Color = "E9E5DC";
        internal const string EquityThemeAccent1Color = "D34817";
        internal const string EquityThemeAccent2Color = "9B2D1F";
        internal const string EquityThemeAccent3Color = "A28E6A";
        internal const string EquityThemeAccent4Color = "956251";
        internal const string EquityThemeAccent5Color = "918485";
        internal const string EquityThemeAccent6Color = "855D5D";
        internal const string EquityThemeHyperlink = "CC9900";
        internal const string EquityThemeFollowedHyperlinkColor = "96A9A9";

        internal const string EssentialThemeName = "SpreadsheetLight Essential";
        internal const string EssentialThemeMajorLatinFont = "Arial Black";
        internal const string EssentialThemeMinorLatinFont = "Arial";
        internal const string EssentialThemeDark1Color = "000000";
        internal const string EssentialThemeLight1Color = "FFFFFF";
        internal const string EssentialThemeDark2Color = "D1282E";
        internal const string EssentialThemeLight2Color = "C8C8B1";
        internal const string EssentialThemeAccent1Color = "7A7A7A";
        internal const string EssentialThemeAccent2Color = "F5C201";
        internal const string EssentialThemeAccent3Color = "526DB0";
        internal const string EssentialThemeAccent4Color = "989AAC";
        internal const string EssentialThemeAccent5Color = "DC5924";
        internal const string EssentialThemeAccent6Color = "B4B392";
        internal const string EssentialThemeHyperlink = "CC9900";
        internal const string EssentialThemeFollowedHyperlinkColor = "969696";

        internal const string ExecutiveThemeName = "SpreadsheetLight Executive";
        internal const string ExecutiveThemeMajorLatinFont = "Century Gothic";
        internal const string ExecutiveThemeMinorLatinFont = "Palatino Linotype";
        internal const string ExecutiveThemeDark1Color = "000000";
        internal const string ExecutiveThemeLight1Color = "FFFFFF";
        internal const string ExecutiveThemeDark2Color = "2F5897";
        internal const string ExecutiveThemeLight2Color = "E4E9EF";
        internal const string ExecutiveThemeAccent1Color = "6076B4";
        internal const string ExecutiveThemeAccent2Color = "9C5252";
        internal const string ExecutiveThemeAccent3Color = "E68422";
        internal const string ExecutiveThemeAccent4Color = "846648";
        internal const string ExecutiveThemeAccent5Color = "63891F";
        internal const string ExecutiveThemeAccent6Color = "758085";
        internal const string ExecutiveThemeHyperlink = "3399FF";
        internal const string ExecutiveThemeFollowedHyperlinkColor = "B2B2B2";

        internal const string FlowThemeName = "SpreadsheetLight Flow";
        internal const string FlowThemeMajorLatinFont = "Calibri";
        internal const string FlowThemeMinorLatinFont = "Constantia";
        internal const string FlowThemeDark1Color = "000000";
        internal const string FlowThemeLight1Color = "FFFFFF";
        internal const string FlowThemeDark2Color = "04617B";
        internal const string FlowThemeLight2Color = "DBF5F9";
        internal const string FlowThemeAccent1Color = "0F6FC6";
        internal const string FlowThemeAccent2Color = "009DD9";
        internal const string FlowThemeAccent3Color = "0BD0D9";
        internal const string FlowThemeAccent4Color = "10CF9B";
        internal const string FlowThemeAccent5Color = "7CCA62";
        internal const string FlowThemeAccent6Color = "A5C249";
        internal const string FlowThemeHyperlink = "E2D700";
        internal const string FlowThemeFollowedHyperlinkColor = "85DFD0";

        internal const string FoundryThemeName = "SpreadsheetLight Foundry";
        internal const string FoundryThemeMajorLatinFont = "Rockwell";
        internal const string FoundryThemeMinorLatinFont = "Rockwell";
        internal const string FoundryThemeDark1Color = "000000";
        internal const string FoundryThemeLight1Color = "FFFFFF";
        internal const string FoundryThemeDark2Color = "676A55";
        internal const string FoundryThemeLight2Color = "EAEBDE";
        internal const string FoundryThemeAccent1Color = "72A376";
        internal const string FoundryThemeAccent2Color = "B0CCB0";
        internal const string FoundryThemeAccent3Color = "A8CDD7";
        internal const string FoundryThemeAccent4Color = "C0BEAF";
        internal const string FoundryThemeAccent5Color = "CEC597";
        internal const string FoundryThemeAccent6Color = "E8B7B7";
        internal const string FoundryThemeHyperlink = "DB5353";
        internal const string FoundryThemeFollowedHyperlinkColor = "903638";

        internal const string GridThemeName = "SpreadsheetLight Grid";
        internal const string GridThemeMajorLatinFont = "Franklin Gothic Medium";
        internal const string GridThemeMinorLatinFont = "Franklin Gothic Medium";
        internal const string GridThemeDark1Color = "000000";
        internal const string GridThemeLight1Color = "FFFFFF";
        internal const string GridThemeDark2Color = "534949";
        internal const string GridThemeLight2Color = "CCD1B9";
        internal const string GridThemeAccent1Color = "C66951";
        internal const string GridThemeAccent2Color = "BF974D";
        internal const string GridThemeAccent3Color = "928B70";
        internal const string GridThemeAccent4Color = "87706B";
        internal const string GridThemeAccent5Color = "94734E";
        internal const string GridThemeAccent6Color = "6F777D";
        internal const string GridThemeHyperlink = "CC9900";
        internal const string GridThemeFollowedHyperlinkColor = "C0C0C0";

        internal const string HardcoverThemeName = "SpreadsheetLight Hardcover";
        internal const string HardcoverThemeMajorLatinFont = "Book Antiqua";
        internal const string HardcoverThemeMinorLatinFont = "Book Antiqua";
        internal const string HardcoverThemeDark1Color = "000000";
        internal const string HardcoverThemeLight1Color = "FFFFFF";
        internal const string HardcoverThemeDark2Color = "895D1D";
        internal const string HardcoverThemeLight2Color = "ECE9C6";
        internal const string HardcoverThemeAccent1Color = "873624";
        internal const string HardcoverThemeAccent2Color = "D6862D";
        internal const string HardcoverThemeAccent3Color = "D0BE40";
        internal const string HardcoverThemeAccent4Color = "877F6C";
        internal const string HardcoverThemeAccent5Color = "972109";
        internal const string HardcoverThemeAccent6Color = "AEB795";
        internal const string HardcoverThemeHyperlink = "CC9900";
        internal const string HardcoverThemeFollowedHyperlinkColor = "B2B2B2";

        internal const string HorizonThemeName = "SpreadsheetLight Horizon";
        internal const string HorizonThemeMajorLatinFont = "Arial Narrow";
        internal const string HorizonThemeMinorLatinFont = "Arial Narrow";
        internal const string HorizonThemeDark1Color = "000000";
        internal const string HorizonThemeLight1Color = "FFFFFF";
        internal const string HorizonThemeDark2Color = "1F2123";
        internal const string HorizonThemeLight2Color = "DC9E1F";
        internal const string HorizonThemeAccent1Color = "7E97AD";
        internal const string HorizonThemeAccent2Color = "CC8E60";
        internal const string HorizonThemeAccent3Color = "7A6A60";
        internal const string HorizonThemeAccent4Color = "B4936D";
        internal const string HorizonThemeAccent5Color = "67787B";
        internal const string HorizonThemeAccent6Color = "9D936F";
        internal const string HorizonThemeHyperlink = "646464";
        internal const string HorizonThemeFollowedHyperlinkColor = "969696";

        internal const string MedianThemeName = "SpreadsheetLight Median";
        internal const string MedianThemeMajorLatinFont = "Tw Cen MT";
        internal const string MedianThemeMinorLatinFont = "Tw Cen MT";
        internal const string MedianThemeDark1Color = "000000";
        internal const string MedianThemeLight1Color = "FFFFFF";
        internal const string MedianThemeDark2Color = "775F55";
        internal const string MedianThemeLight2Color = "EBDDC3";
        internal const string MedianThemeAccent1Color = "94B6D2";
        internal const string MedianThemeAccent2Color = "DD8047";
        internal const string MedianThemeAccent3Color = "A5AB81";
        internal const string MedianThemeAccent4Color = "D8B25C";
        internal const string MedianThemeAccent5Color = "7BA79D";
        internal const string MedianThemeAccent6Color = "968C8C";
        internal const string MedianThemeHyperlink = "F7B615";
        internal const string MedianThemeFollowedHyperlinkColor = "704404";

        internal const string MetroThemeName = "SpreadsheetLight Metro";
        internal const string MetroThemeMajorLatinFont = "Consolas";
        internal const string MetroThemeMinorLatinFont = "Corbel";
        internal const string MetroThemeDark1Color = "000000";
        internal const string MetroThemeLight1Color = "FFFFFF";
        internal const string MetroThemeDark2Color = "4E5B6F";
        internal const string MetroThemeLight2Color = "D6ECFF";
        internal const string MetroThemeAccent1Color = "7FD13B";
        internal const string MetroThemeAccent2Color = "EA157A";
        internal const string MetroThemeAccent3Color = "FEB80A";
        internal const string MetroThemeAccent4Color = "00ADDC";
        internal const string MetroThemeAccent5Color = "738AC8";
        internal const string MetroThemeAccent6Color = "1AB39F";
        internal const string MetroThemeHyperlink = "EB8803";
        internal const string MetroThemeFollowedHyperlinkColor = "5F7791";

        internal const string ModuleThemeName = "SpreadsheetLight Module";
        internal const string ModuleThemeMajorLatinFont = "Corbel";
        internal const string ModuleThemeMinorLatinFont = "Corbel";
        internal const string ModuleThemeDark1Color = "000000";
        internal const string ModuleThemeLight1Color = "FFFFFF";
        internal const string ModuleThemeDark2Color = "5A6378";
        internal const string ModuleThemeLight2Color = "D4D4D6";
        internal const string ModuleThemeAccent1Color = "F0AD00";
        internal const string ModuleThemeAccent2Color = "60B5CC";
        internal const string ModuleThemeAccent3Color = "E66C7D";
        internal const string ModuleThemeAccent4Color = "6BB76D";
        internal const string ModuleThemeAccent5Color = "E88651";
        internal const string ModuleThemeAccent6Color = "C64847";
        internal const string ModuleThemeHyperlink = "168BBA";
        internal const string ModuleThemeFollowedHyperlinkColor = "680000";

        internal const string NewsprintThemeName = "SpreadsheetLight Newsprint";
        internal const string NewsprintThemeMajorLatinFont = "Impact";
        internal const string NewsprintThemeMinorLatinFont = "Times New Roman";
        internal const string NewsprintThemeDark1Color = "000000";
        internal const string NewsprintThemeLight1Color = "FFFFFF";
        internal const string NewsprintThemeDark2Color = "303030";
        internal const string NewsprintThemeLight2Color = "DEDEE0";
        internal const string NewsprintThemeAccent1Color = "AD0101";
        internal const string NewsprintThemeAccent2Color = "726056";
        internal const string NewsprintThemeAccent3Color = "AC956E";
        internal const string NewsprintThemeAccent4Color = "808DA9";
        internal const string NewsprintThemeAccent5Color = "424E5B";
        internal const string NewsprintThemeAccent6Color = "730E00";
        internal const string NewsprintThemeHyperlink = "D26900";
        internal const string NewsprintThemeFollowedHyperlinkColor = "D89243";

        internal const string OpulentThemeName = "SpreadsheetLight Opulent";
        internal const string OpulentThemeMajorLatinFont = "Trebuchet MS";
        internal const string OpulentThemeMinorLatinFont = "Trebuchet MS";
        internal const string OpulentThemeDark1Color = "000000";
        internal const string OpulentThemeLight1Color = "FFFFFF";
        internal const string OpulentThemeDark2Color = "B13F9A";
        internal const string OpulentThemeLight2Color = "F4E7ED";
        internal const string OpulentThemeAccent1Color = "B83D68";
        internal const string OpulentThemeAccent2Color = "AC66BB";
        internal const string OpulentThemeAccent3Color = "DE6C36";
        internal const string OpulentThemeAccent4Color = "F9B639";
        internal const string OpulentThemeAccent5Color = "CF6DA4";
        internal const string OpulentThemeAccent6Color = "FA8D3D";
        internal const string OpulentThemeHyperlink = "FFDE66";
        internal const string OpulentThemeFollowedHyperlinkColor = "D490C5";

        internal const string OrielThemeName = "SpreadsheetLight Oriel";
        internal const string OrielThemeMajorLatinFont = "Century Schoolbook";
        internal const string OrielThemeMinorLatinFont = "Century Schoolbook";
        internal const string OrielThemeDark1Color = "000000";
        internal const string OrielThemeLight1Color = "FFFFFF";
        internal const string OrielThemeDark2Color = "575F6D";
        internal const string OrielThemeLight2Color = "FFF39D";
        internal const string OrielThemeAccent1Color = "FE8637";
        internal const string OrielThemeAccent2Color = "7598D9";
        internal const string OrielThemeAccent3Color = "B32C16";
        internal const string OrielThemeAccent4Color = "F5CD2D";
        internal const string OrielThemeAccent5Color = "AEBAD5";
        internal const string OrielThemeAccent6Color = "777C84";
        internal const string OrielThemeHyperlink = "D2611C";
        internal const string OrielThemeFollowedHyperlinkColor = "3B435B";

        internal const string OriginThemeName = "SpreadsheetLight Origin";
        internal const string OriginThemeMajorLatinFont = "Bookman Old Style";
        internal const string OriginThemeMinorLatinFont = "Gill Sans MT";
        internal const string OriginThemeDark1Color = "000000";
        internal const string OriginThemeLight1Color = "FFFFFF";
        internal const string OriginThemeDark2Color = "464653";
        internal const string OriginThemeLight2Color = "DDE9EC";
        internal const string OriginThemeAccent1Color = "727CA3";
        internal const string OriginThemeAccent2Color = "9FB8CD";
        internal const string OriginThemeAccent3Color = "D2DA7A";
        internal const string OriginThemeAccent4Color = "FADA7A";
        internal const string OriginThemeAccent5Color = "B88472";
        internal const string OriginThemeAccent6Color = "8E736A";
        internal const string OriginThemeHyperlink = "B292CA";
        internal const string OriginThemeFollowedHyperlinkColor = "6B5680";

        internal const string PaperThemeName = "SpreadsheetLight Paper";
        internal const string PaperThemeMajorLatinFont = "Constantia";
        internal const string PaperThemeMinorLatinFont = "Constantia";
        internal const string PaperThemeDark1Color = "000000";
        internal const string PaperThemeLight1Color = "FFFFFF";
        internal const string PaperThemeDark2Color = "444D26";
        internal const string PaperThemeLight2Color = "FEFAC9";
        internal const string PaperThemeAccent1Color = "A5B592";
        internal const string PaperThemeAccent2Color = "F3A447";
        internal const string PaperThemeAccent3Color = "E7BC29";
        internal const string PaperThemeAccent4Color = "D092A7";
        internal const string PaperThemeAccent5Color = "9C85C0";
        internal const string PaperThemeAccent6Color = "809EC2";
        internal const string PaperThemeHyperlink = "8E58B6";
        internal const string PaperThemeFollowedHyperlinkColor = "7F6F6F";

        internal const string PerspectiveThemeName = "SpreadsheetLight Perspective";
        internal const string PerspectiveThemeMajorLatinFont = "Arial";
        internal const string PerspectiveThemeMinorLatinFont = "Arial";
        internal const string PerspectiveThemeDark1Color = "000000";
        internal const string PerspectiveThemeLight1Color = "FFFFFF";
        internal const string PerspectiveThemeDark2Color = "283138";
        internal const string PerspectiveThemeLight2Color = "FF8600";
        internal const string PerspectiveThemeAccent1Color = "838D9B";
        internal const string PerspectiveThemeAccent2Color = "D2610C";
        internal const string PerspectiveThemeAccent3Color = "80716A";
        internal const string PerspectiveThemeAccent4Color = "94147C";
        internal const string PerspectiveThemeAccent5Color = "5D5AD2";
        internal const string PerspectiveThemeAccent6Color = "6F6C7D";
        internal const string PerspectiveThemeHyperlink = "6187E3";
        internal const string PerspectiveThemeFollowedHyperlinkColor = "7B8EB8";

        internal const string PushpinThemeName = "SpreadsheetLight Pushpin";
        internal const string PushpinThemeMajorLatinFont = "Constantia";
        internal const string PushpinThemeMinorLatinFont = "Franklin Gothic Book";
        internal const string PushpinThemeDark1Color = "000000";
        internal const string PushpinThemeLight1Color = "FFFFFF";
        internal const string PushpinThemeDark2Color = "465E9C";
        internal const string PushpinThemeLight2Color = "CCDDEA";
        internal const string PushpinThemeAccent1Color = "FDA023";
        internal const string PushpinThemeAccent2Color = "AA2B1E";
        internal const string PushpinThemeAccent3Color = "71685C";
        internal const string PushpinThemeAccent4Color = "64A73B";
        internal const string PushpinThemeAccent5Color = "EB5605";
        internal const string PushpinThemeAccent6Color = "B9CA1A";
        internal const string PushpinThemeHyperlink = "D83E2C";
        internal const string PushpinThemeFollowedHyperlinkColor = "ED7D27";

        internal const string SlipstreamThemeName = "SpreadsheetLight Slipstream";
        internal const string SlipstreamThemeMajorLatinFont = "Trebuchet MS";
        internal const string SlipstreamThemeMinorLatinFont = "Trebuchet MS";
        internal const string SlipstreamThemeDark1Color = "000000";
        internal const string SlipstreamThemeLight1Color = "FFFFFF";
        internal const string SlipstreamThemeDark2Color = "212745";
        internal const string SlipstreamThemeLight2Color = "B4DCFA";
        internal const string SlipstreamThemeAccent1Color = "4E67C8";
        internal const string SlipstreamThemeAccent2Color = "5ECCF3";
        internal const string SlipstreamThemeAccent3Color = "A7EA52";
        internal const string SlipstreamThemeAccent4Color = "5DCEAF";
        internal const string SlipstreamThemeAccent5Color = "FF8021";
        internal const string SlipstreamThemeAccent6Color = "F14124";
        internal const string SlipstreamThemeHyperlink = "56C7AA";
        internal const string SlipstreamThemeFollowedHyperlinkColor = "59A8D1";

        internal const string SolsticeThemeName = "SpreadsheetLight Solstice";
        internal const string SolsticeThemeMajorLatinFont = "Gill Sans MT";
        internal const string SolsticeThemeMinorLatinFont = "Gill Sans MT";
        internal const string SolsticeThemeDark1Color = "000000";
        internal const string SolsticeThemeLight1Color = "FFFFFF";
        internal const string SolsticeThemeDark2Color = "4F271C";
        internal const string SolsticeThemeLight2Color = "E7DEC9";
        internal const string SolsticeThemeAccent1Color = "3891A7";
        internal const string SolsticeThemeAccent2Color = "FEB80A";
        internal const string SolsticeThemeAccent3Color = "C32D2E";
        internal const string SolsticeThemeAccent4Color = "84AA33";
        internal const string SolsticeThemeAccent5Color = "964305";
        internal const string SolsticeThemeAccent6Color = "475A8D";
        internal const string SolsticeThemeHyperlink = "8DC765";
        internal const string SolsticeThemeFollowedHyperlinkColor = "AA8A14";

        internal const string TechnicThemeName = "SpreadsheetLight Technic";
        internal const string TechnicThemeMajorLatinFont = "Franklin Gothic Book";
        internal const string TechnicThemeMinorLatinFont = "Arial";
        internal const string TechnicThemeDark1Color = "000000";
        internal const string TechnicThemeLight1Color = "FFFFFF";
        internal const string TechnicThemeDark2Color = "3B3B3B";
        internal const string TechnicThemeLight2Color = "D4D2D0";
        internal const string TechnicThemeAccent1Color = "6EA0B0";
        internal const string TechnicThemeAccent2Color = "CCAF0A";
        internal const string TechnicThemeAccent3Color = "8D89A4";
        internal const string TechnicThemeAccent4Color = "748560";
        internal const string TechnicThemeAccent5Color = "9E9273";
        internal const string TechnicThemeAccent6Color = "7E848D";
        internal const string TechnicThemeHyperlink = "00C8C3";
        internal const string TechnicThemeFollowedHyperlinkColor = "A116E0";

        internal const string ThatchThemeName = "SpreadsheetLight Thatch";
        internal const string ThatchThemeMajorLatinFont = "Tw Cen MT";
        internal const string ThatchThemeMinorLatinFont = "Tw Cen MT";
        internal const string ThatchThemeDark1Color = "000000";
        internal const string ThatchThemeLight1Color = "FFFFFF";
        internal const string ThatchThemeDark2Color = "1D3641";
        internal const string ThatchThemeLight2Color = "DFE6D0";
        internal const string ThatchThemeAccent1Color = "759AA5";
        internal const string ThatchThemeAccent2Color = "CFC60D";
        internal const string ThatchThemeAccent3Color = "99987F";
        internal const string ThatchThemeAccent4Color = "90AC97";
        internal const string ThatchThemeAccent5Color = "FFAD1C";
        internal const string ThatchThemeAccent6Color = "B9AB6F";
        internal const string ThatchThemeHyperlink = "66AACD";
        internal const string ThatchThemeFollowedHyperlinkColor = "809DB3";

        internal const string TrekThemeName = "SpreadsheetLight Trek";
        internal const string TrekThemeMajorLatinFont = "Franklin Gothic Medium";
        internal const string TrekThemeMinorLatinFont = "Franklin Gothic Book";
        internal const string TrekThemeDark1Color = "000000";
        internal const string TrekThemeLight1Color = "FFFFFF";
        internal const string TrekThemeDark2Color = "4E3B30";
        internal const string TrekThemeLight2Color = "FBEEC9";
        internal const string TrekThemeAccent1Color = "F0A22E";
        internal const string TrekThemeAccent2Color = "A5644E";
        internal const string TrekThemeAccent3Color = "B58B80";
        internal const string TrekThemeAccent4Color = "C3986D";
        internal const string TrekThemeAccent5Color = "A19574";
        internal const string TrekThemeAccent6Color = "C17529";
        internal const string TrekThemeHyperlink = "AD1F1F";
        internal const string TrekThemeFollowedHyperlinkColor = "FFC42F";

        internal const string UrbanThemeName = "SpreadsheetLight Urban";
        internal const string UrbanThemeMajorLatinFont = "Trebuchet MS";
        internal const string UrbanThemeMinorLatinFont = "Georgia";
        internal const string UrbanThemeDark1Color = "000000";
        internal const string UrbanThemeLight1Color = "FFFFFF";
        internal const string UrbanThemeDark2Color = "424456";
        internal const string UrbanThemeLight2Color = "DEDEDE";
        internal const string UrbanThemeAccent1Color = "53548A";
        internal const string UrbanThemeAccent2Color = "438086";
        internal const string UrbanThemeAccent3Color = "A04DA3";
        internal const string UrbanThemeAccent4Color = "C4652D";
        internal const string UrbanThemeAccent5Color = "8B5D3D";
        internal const string UrbanThemeAccent6Color = "5C92B5";
        internal const string UrbanThemeHyperlink = "67AFBD";
        internal const string UrbanThemeFollowedHyperlinkColor = "C2A874";

        internal const string VerveThemeName = "SpreadsheetLight Verve";
        internal const string VerveThemeMajorLatinFont = "Century Gothic";
        internal const string VerveThemeMinorLatinFont = "Century Gothic";
        internal const string VerveThemeDark1Color = "000000";
        internal const string VerveThemeLight1Color = "FFFFFF";
        internal const string VerveThemeDark2Color = "666666";
        internal const string VerveThemeLight2Color = "D2D2D2";
        internal const string VerveThemeAccent1Color = "FF388C";
        internal const string VerveThemeAccent2Color = "E40059";
        internal const string VerveThemeAccent3Color = "9C007F";
        internal const string VerveThemeAccent4Color = "68007F";
        internal const string VerveThemeAccent5Color = "005BD3";
        internal const string VerveThemeAccent6Color = "00349E";
        internal const string VerveThemeHyperlink = "17BBFD";
        internal const string VerveThemeFollowedHyperlinkColor = "FF79C2";

        internal const string WaveformThemeName = "SpreadsheetLight Waveform";
        internal const string WaveformThemeMajorLatinFont = "Candara";
        internal const string WaveformThemeMinorLatinFont = "Candara";
        internal const string WaveformThemeDark1Color = "000000";
        internal const string WaveformThemeLight1Color = "FFFFFF";
        internal const string WaveformThemeDark2Color = "073E87";
        internal const string WaveformThemeLight2Color = "C6E7FC";
        internal const string WaveformThemeAccent1Color = "31B6FD";
        internal const string WaveformThemeAccent2Color = "4584D3";
        internal const string WaveformThemeAccent3Color = "5BD078";
        internal const string WaveformThemeAccent4Color = "A5D028";
        internal const string WaveformThemeAccent5Color = "F5C040";
        internal const string WaveformThemeAccent6Color = "05E0DB";
        internal const string WaveformThemeHyperlink = "0080FF";
        internal const string WaveformThemeFollowedHyperlinkColor = "5EAEFF";

        internal const string AutumnThemeName = "SpreadsheetLight Autumn";
        internal const string AutumnThemeMajorLatinFont = "Verdana";
        internal const string AutumnThemeMinorLatinFont = "Verdana";
        internal const string AutumnThemeDark1Color = "000000";
        internal const string AutumnThemeLight1Color = "FFFFFF";
        internal const string AutumnThemeDark2Color = "B01F0F";
        internal const string AutumnThemeLight2Color = "FF9000";
        internal const string AutumnThemeAccent1Color = "ED4600";
        internal const string AutumnThemeAccent2Color = "C4D73F";
        internal const string AutumnThemeAccent3Color = "FFCE2D";
        internal const string AutumnThemeAccent4Color = "FFA600";
        internal const string AutumnThemeAccent5Color = "ED5E00";
        internal const string AutumnThemeAccent6Color = "C62D03";
        internal const string AutumnThemeHyperlink = "408080";
        internal const string AutumnThemeFollowedHyperlinkColor = "5EAEAE";

        internal const string DecaturThemeName = "SpreadsheetLight Decatur";
        internal const string DecaturThemeMajorLatinFont = "Bodoni MT Condensed";
        internal const string DecaturThemeMinorLatinFont = "Franklin Gothic Book";
        internal const string DecaturThemeDark1Color = "000000";
        internal const string DecaturThemeLight1Color = "FFFFFF";
        internal const string DecaturThemeDark2Color = "55554A";
        internal const string DecaturThemeLight2Color = "D7DAE1";
        internal const string DecaturThemeAccent1Color = "F4680B";
        internal const string DecaturThemeAccent2Color = "ABB19F";
        internal const string DecaturThemeAccent3Color = "948774";
        internal const string DecaturThemeAccent4Color = "7EB8E7";
        internal const string DecaturThemeAccent5Color = "E3B651";
        internal const string DecaturThemeAccent6Color = "96756C";
        internal const string DecaturThemeHyperlink = "66AACD";
        internal const string DecaturThemeFollowedHyperlinkColor = "809DB3";

        internal const string KilterThemeName = "SpreadsheetLight Kilter";
        internal const string KilterThemeMajorLatinFont = "Rockwell";
        internal const string KilterThemeMinorLatinFont = "Rockwell";
        internal const string KilterThemeDark1Color = "000000";
        internal const string KilterThemeLight1Color = "FFFFFF";
        internal const string KilterThemeDark2Color = "318FC5";
        internal const string KilterThemeLight2Color = "AEE8FB";
        internal const string KilterThemeAccent1Color = "76C5EF";
        internal const string KilterThemeAccent2Color = "FEA022";
        internal const string KilterThemeAccent3Color = "FF6700";
        internal const string KilterThemeAccent4Color = "70A525";
        internal const string KilterThemeAccent5Color = "A5D848";
        internal const string KilterThemeAccent6Color = "20768C";
        internal const string KilterThemeHyperlink = "7AB6E8";
        internal const string KilterThemeFollowedHyperlinkColor = "83B0D3";

        internal const string MacroThemeName = "SpreadsheetLight Macro";
        internal const string MacroThemeMajorLatinFont = "Calibri";
        internal const string MacroThemeMinorLatinFont = "Calibri";
        internal const string MacroThemeDark1Color = "000000";
        internal const string MacroThemeLight1Color = "FFFFFF";
        internal const string MacroThemeDark2Color = "3F3F4D";
        internal const string MacroThemeLight2Color = "DDDDDD";
        internal const string MacroThemeAccent1Color = "A51009";
        internal const string MacroThemeAccent2Color = "DE7014";
        internal const string MacroThemeAccent3Color = "704836";
        internal const string MacroThemeAccent4Color = "F2B431";
        internal const string MacroThemeAccent5Color = "7F221D";
        internal const string MacroThemeAccent6Color = "CDAC77";
        internal const string MacroThemeHyperlink = "F5B123";
        internal const string MacroThemeFollowedHyperlinkColor = "E19B0B";

        internal const string MylarThemeName = "SpreadsheetLight Mylar";
        internal const string MylarThemeMajorLatinFont = "Corbel";
        internal const string MylarThemeMinorLatinFont = "Corbel";
        internal const string MylarThemeDark1Color = "000000";
        internal const string MylarThemeLight1Color = "FFFFFF";
        internal const string MylarThemeDark2Color = "656162";
        internal const string MylarThemeLight2Color = "E0DACC";
        internal const string MylarThemeAccent1Color = "4A5A7A";
        internal const string MylarThemeAccent2Color = "F7BD40";
        internal const string MylarThemeAccent3Color = "975C00";
        internal const string MylarThemeAccent4Color = "754D41";
        internal const string MylarThemeAccent5Color = "838995";
        internal const string MylarThemeAccent6Color = "687B66";
        internal const string MylarThemeHyperlink = "B5740B";
        internal const string MylarThemeFollowedHyperlinkColor = "7483A0";

        internal const string SketchbookThemeName = "SpreadsheetLight Sketchbook";
        internal const string SketchbookThemeMajorLatinFont = "Cambria";
        internal const string SketchbookThemeMinorLatinFont = "Cambria";
        internal const string SketchbookThemeDark1Color = "000000";
        internal const string SketchbookThemeLight1Color = "FFFFFF";
        internal const string SketchbookThemeDark2Color = "4C1304";
        internal const string SketchbookThemeLight2Color = "FFFEE6";
        internal const string SketchbookThemeAccent1Color = "A63212";
        internal const string SketchbookThemeAccent2Color = "E68230";
        internal const string SketchbookThemeAccent3Color = "9BB05E";
        internal const string SketchbookThemeAccent4Color = "6B9BC7";
        internal const string SketchbookThemeAccent5Color = "4E66B2";
        internal const string SketchbookThemeAccent6Color = "8976AC";
        internal const string SketchbookThemeHyperlink = "942408";
        internal const string SketchbookThemeFollowedHyperlinkColor = "B34F17";

        internal const string SohoThemeName = "SpreadsheetLight Soho";
        internal const string SohoThemeMajorLatinFont = "Candara";
        internal const string SohoThemeMinorLatinFont = "Candara";
        internal const string SohoThemeDark1Color = "2E2224";
        internal const string SohoThemeLight1Color = "FFFFFF";
        internal const string SohoThemeDark2Color = "48231E";
        internal const string SohoThemeLight2Color = "CBD8DD";
        internal const string SohoThemeAccent1Color = "61625E";
        internal const string SohoThemeAccent2Color = "964D2C";
        internal const string SohoThemeAccent3Color = "66553E";
        internal const string SohoThemeAccent4Color = "848058";
        internal const string SohoThemeAccent5Color = "AFA14B";
        internal const string SohoThemeAccent6Color = "AD7D4D";
        internal const string SohoThemeHyperlink = "FFDE66";
        internal const string SohoThemeFollowedHyperlinkColor = "C0AEBC";

        internal const string SpringThemeName = "SpreadsheetLight Spring";
        internal const string SpringThemeMajorLatinFont = "Verdana";
        internal const string SpringThemeMinorLatinFont = "Verdana";
        internal const string SpringThemeDark1Color = "000000";
        internal const string SpringThemeLight1Color = "FFFFFF";
        internal const string SpringThemeDark2Color = "66822D";
        internal const string SpringThemeLight2Color = "BEEA73";
        internal const string SpringThemeAccent1Color = "C1EC76";
        internal const string SpringThemeAccent2Color = "8FE28A";
        internal const string SpringThemeAccent3Color = "F3BF45";
        internal const string SpringThemeAccent4Color = "F47E5A";
        internal const string SpringThemeAccent5Color = "F489CF";
        internal const string SpringThemeAccent6Color = "B56FF4";
        internal const string SpringThemeHyperlink = "408080";
        internal const string SpringThemeFollowedHyperlinkColor = "5EAEAE";

        internal const string SummerThemeName = "SpreadsheetLight Summer";
        internal const string SummerThemeMajorLatinFont = "Verdana";
        internal const string SummerThemeMinorLatinFont = "Verdana";
        internal const string SummerThemeDark1Color = "000000";
        internal const string SummerThemeLight1Color = "FFFFFF";
        internal const string SummerThemeDark2Color = "E89117";
        internal const string SummerThemeLight2Color = "FEDD78";
        internal const string SummerThemeAccent1Color = "A1B633";
        internal const string SummerThemeAccent2Color = "C4D73F";
        internal const string SummerThemeAccent3Color = "FFCE2D";
        internal const string SummerThemeAccent4Color = "FFA600";
        internal const string SummerThemeAccent5Color = "ED5E00";
        internal const string SummerThemeAccent6Color = "C62D03";
        internal const string SummerThemeHyperlink = "408080";
        internal const string SummerThemeFollowedHyperlinkColor = "5EAEAE";

        internal const string ThermalThemeName = "SpreadsheetLight Thermal";
        internal const string ThermalThemeMajorLatinFont = "Calibri";
        internal const string ThermalThemeMinorLatinFont = "Calibri";
        internal const string ThermalThemeDark1Color = "4D5B6B";
        internal const string ThermalThemeLight1Color = "FFFFFF";
        internal const string ThermalThemeDark2Color = "675D59";
        internal const string ThermalThemeLight2Color = "E8DED8";
        internal const string ThermalThemeAccent1Color = "FF7605";
        internal const string ThermalThemeAccent2Color = "7F7F7F";
        internal const string ThermalThemeAccent3Color = "7F5185";
        internal const string ThermalThemeAccent4Color = "89AAD3";
        internal const string ThermalThemeAccent5Color = "8F5B4B";
        internal const string ThermalThemeAccent6Color = "C84340";
        internal const string ThermalThemeHyperlink = "89AAD3";
        internal const string ThermalThemeFollowedHyperlinkColor = "795185";

        internal const string TradeshowThemeName = "SpreadsheetLight Tradeshow";
        internal const string TradeshowThemeMajorLatinFont = "Arial Black";
        internal const string TradeshowThemeMinorLatinFont = "Candara";
        internal const string TradeshowThemeDark1Color = "3F3F3F";
        internal const string TradeshowThemeLight1Color = "FFFFFF";
        internal const string TradeshowThemeDark2Color = "7DAFC3";
        internal const string TradeshowThemeLight2Color = "E5E4DF";
        internal const string TradeshowThemeAccent1Color = "7C959A";
        internal const string TradeshowThemeAccent2Color = "DB8631";
        internal const string TradeshowThemeAccent3Color = "E3CC5A";
        internal const string TradeshowThemeAccent4Color = "ACADA8";
        internal const string TradeshowThemeAccent5Color = "927C61";
        internal const string TradeshowThemeAccent6Color = "B3B435";
        internal const string TradeshowThemeHyperlink = "0079A4";
        internal const string TradeshowThemeFollowedHyperlinkColor = "595959";

        internal const string UrbanPopThemeName = "SpreadsheetLight UrbanPop";
        internal const string UrbanPopThemeMajorLatinFont = "Gill Sans MT";
        internal const string UrbanPopThemeMinorLatinFont = "Gill Sans MT";
        internal const string UrbanPopThemeDark1Color = "000000";
        internal const string UrbanPopThemeLight1Color = "FFFFFF";
        internal const string UrbanPopThemeDark2Color = "282828";
        internal const string UrbanPopThemeLight2Color = "D4D4D4";
        internal const string UrbanPopThemeAccent1Color = "86CE24";
        internal const string UrbanPopThemeAccent2Color = "00A2E6";
        internal const string UrbanPopThemeAccent3Color = "FAC810";
        internal const string UrbanPopThemeAccent4Color = "7D8F8C";
        internal const string UrbanPopThemeAccent5Color = "D06B20";
        internal const string UrbanPopThemeAccent6Color = "958B8B";
        internal const string UrbanPopThemeHyperlink = "FF9900";
        internal const string UrbanPopThemeFollowedHyperlinkColor = "969696";

        internal const string WinterThemeName = "SpreadsheetLight Winter";
        internal const string WinterThemeMajorLatinFont = "Verdana";
        internal const string WinterThemeMinorLatinFont = "Verdana";
        internal const string WinterThemeDark1Color = "000000";
        internal const string WinterThemeLight1Color = "FFFFFF";
        internal const string WinterThemeDark2Color = "1F7BB6";
        internal const string WinterThemeLight2Color = "C5E1FE";
        internal const string WinterThemeAccent1Color = "B2BDC1";
        internal const string WinterThemeAccent2Color = "767D83";
        internal const string WinterThemeAccent3Color = "3E505C";
        internal const string WinterThemeAccent4Color = "386489";
        internal const string WinterThemeAccent5Color = "4C80AF";
        internal const string WinterThemeAccent6Color = "7DA7D1";
        internal const string WinterThemeHyperlink = "408080";
        internal const string WinterThemeFollowedHyperlinkColor = "5EAEAE";

        // not exactly constants? I don't care. They look like constants when you're typing.
        // That's good enough for me...
        internal static DateTime Epoch1900()
        {
            return new DateTime(1900, 1, 1, 0, 0, 0, 0);
        }

        internal static DateTime Epoch1904()
        {
             return new DateTime(1904, 1, 1, 0, 0, 0, 0);
        }
    }
}
