﻿using System;
using System.IO;
using DocumentFormat.OpenXml.Packaging;

namespace SpreadsheetLight
{
    public partial class SLDocument
    {
        /// <summary>
        /// Get the spreadsheet's theme settings.
        /// </summary>
        /// <returns></returns>
        public SLThemeSettings GetThemeSettings()
        {
            SLThemeSettings ts = new SLThemeSettings();
            ts.ThemeName = SimpleTheme.ThemeName;
            ts.MajorLatinFont = SimpleTheme.MajorLatinFont;
            ts.MinorLatinFont = SimpleTheme.MinorLatinFont;

            ts.Dark1Color = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.Dark1Color];
            ts.Light1Color = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.Light1Color];
            ts.Dark2Color = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.Dark2Color];
            ts.Light2Color = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.Light2Color];
            ts.Accent1Color = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.Accent1Color];
            ts.Accent2Color = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.Accent2Color];
            ts.Accent3Color = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.Accent3Color];
            ts.Accent4Color = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.Accent4Color];
            ts.Accent5Color = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.Accent5Color];
            ts.Accent6Color = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.Accent6Color];
            ts.Hyperlink = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.Hyperlink];
            ts.FollowedHyperlinkColor = SimpleTheme.listThemeColors[(int)SLThemeColorIndexValues.FollowedHyperlinkColor];

            return ts;
        }

        internal void WriteTheme()
        {
            if (wbp.ThemePart == null)
            {
                ThemePart themePart = wbp.AddNewPart<ThemePart>();

                using (MemoryStream ms = new MemoryStream())
                {
                    StreamWriter sw = new StreamWriter(ms);
                    sw.Write("<a:theme xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" name=\"{0}\">", SimpleTheme.ThemeName);
                    sw.Write("<a:themeElements>");

                    sw.Write("<a:clrScheme name=\"{0}\">", SimpleTheme.ThemeName);
                    sw.Write("<a:dk1><a:srgbClr val=\"{0}\" /></a:dk1>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.Dark1Color]);
                    sw.Write("<a:lt1><a:srgbClr val=\"{0}\" /></a:lt1>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.Light1Color]);
                    sw.Write("<a:dk2><a:srgbClr val=\"{0}\" /></a:dk2>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.Dark2Color]);
                    sw.Write("<a:lt2><a:srgbClr val=\"{0}\" /></a:lt2>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.Light2Color]);
                    sw.Write("<a:accent1><a:srgbClr val=\"{0}\" /></a:accent1>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.Accent1Color]);
                    sw.Write("<a:accent2><a:srgbClr val=\"{0}\" /></a:accent2>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.Accent2Color]);
                    sw.Write("<a:accent3><a:srgbClr val=\"{0}\" /></a:accent3>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.Accent3Color]);
                    sw.Write("<a:accent4><a:srgbClr val=\"{0}\" /></a:accent4>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.Accent4Color]);
                    sw.Write("<a:accent5><a:srgbClr val=\"{0}\" /></a:accent5>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.Accent5Color]);
                    sw.Write("<a:accent6><a:srgbClr val=\"{0}\" /></a:accent6>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.Accent6Color]);
                    sw.Write("<a:hlink><a:srgbClr val=\"{0}\" /></a:hlink>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.Hyperlink]);
                    sw.Write("<a:folHlink><a:srgbClr val=\"{0}\" /></a:folHlink>", SimpleTheme.listThemeColorsHex[(int)SLThemeColorIndexValues.FollowedHyperlinkColor]);
                    sw.Write("</a:clrScheme>");

                    sw.Write("<a:fontScheme name=\"{0}\">", SimpleTheme.ThemeName);
                    sw.Write("<a:majorFont>");
                    sw.Write("<a:latin typeface=\"{0}\" />", SimpleTheme.MajorLatinFont);
                    sw.Write("<a:ea typeface=\"\" />");
                    sw.Write("<a:cs typeface=\"\" />");
                    // start of major supplemental fonts
                    switch (SimpleTheme.InternalThemeType)
                    {
                        case SLThemeTypeValues.Office:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Adjacency:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Angles:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG創英角ｺﾞｼｯｸUB\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Aharoni\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"LilyUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Apex:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG丸ｺﾞｼｯｸM-PRO\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"휴먼옛체\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"黑体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Levenim MT\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Apothecary:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGS明朝B\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY견명조\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"David\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"EucrosiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Aspect:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"굴림\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Austin:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY중고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"幼圆\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Gisha\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"DilleniaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.BlackTie:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Constantia\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Constantia\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐ明朝\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"궁서\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"仿宋\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"標楷體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Civic:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正舒体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Clarity:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正舒体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Composite:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Concourse:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"黑体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Couture:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Constantia\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Constantia\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐ明朝\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"궁서\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"仿宋\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"標楷體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Elemental:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGS明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Browallia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Equity:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"바탕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"幼圆\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Aharoni\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"LilyUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Essential:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY견고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Executive:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY중고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"幼圆\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Gisha\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"DilleniaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Flow:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY중고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"隶书\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Traditional Arabic\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Foundry:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG明朝B\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"바탕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正姚体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"David\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"JasmineUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Grid:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG創英角ｺﾞｼｯｸUB\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY견고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial Bold\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial Bold\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial Bold\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Hardcover:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGS明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"궁서\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Horizon:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY얕은샘물M\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正姚体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Levenim MT\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Median:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGPｺﾞｼｯｸE\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY얕은샘물M\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文仿宋\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Levenim MT\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Metro:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG丸ｺﾞｼｯｸM-PRO\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY중고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文楷体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Levenim MT\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"DilleniaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Module:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY엽서L\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文楷体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Miriam\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"DilleniaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Newsprint:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGP創英角ｺﾞｼｯｸUB\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY견고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tohoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Opulent:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG丸ｺﾞｼｯｸM-PRO\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY그래픽M\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"黑体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Gisha\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"IrisUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Oriel:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐ明朝\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"휴먼매직체\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文楷体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"KodchiangUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Origin:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"標楷體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Browallia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Paper:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"궁서\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文新魏\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"標楷體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Browallia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Perspective:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正舒体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Pushpin:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGS明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY신명조\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Majalla UI\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"David\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Browallia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Slipstream:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY그래픽B\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正姚体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Gisha\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"IrisUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Solstice:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Corbel\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Corbel\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸE\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"휴먼매직체\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文中宋\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Majalla UI\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Technic:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY견고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Thatch:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG創英角ｺﾞｼｯｸUB\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY얕은샘물M\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文仿宋\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Levenim MT\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Trek:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG創英角ｺﾞｼｯｸUB\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"隶书\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Aharoni\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"LilyUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Urban:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正姚体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Verve:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY중고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"幼圆\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Gisha\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"DilleniaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Waveform:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGP明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY그래픽M\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文新魏\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"標楷體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"KodchiangUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Autumn:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"굴림\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Decatur:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY목각파임B\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Kilter:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGS明朝B\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"바탕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正姚体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"David\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"JasmineUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Macro:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Mylar:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文楷体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Sketchbook:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Soho:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY견명조\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文新魏\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"KodchiangUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Spring:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"굴림\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Summer:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"굴림\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Thermal:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Tradeshow:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY견고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.UrbanPop:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文新魏\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Winter:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"굴림\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                    }
                    sw.Write("</a:majorFont>");

                    sw.Write("<a:minorFont>");
                    sw.Write("<a:latin typeface=\"{0}\" />", SimpleTheme.MinorLatinFont);
                    sw.Write("<a:ea typeface=\"\" />");
                    sw.Write("<a:cs typeface=\"\" />");
                    // start of minor supplemental fonts
                    switch (SimpleTheme.InternalThemeType)
                    {
                        case SLThemeTypeValues.Office:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Adjacency:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ 明朝\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Angles:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"隶书\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Apex:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG明朝B\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"David\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"EucrosiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Apothecary:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY견명조\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"幼圆\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Gisha\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"DilleniaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Aspect:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"굴림\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Austin:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY중고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"幼圆\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Gisha\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"DilleniaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.BlackTie:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Constantia\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Constantia\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐ明朝\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"궁서\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"仿宋\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"標楷體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Civic:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐ明朝\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"바탕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正舒体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Clarity:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正舒体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Composite:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Concourse:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"黑体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Couture:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Constantia\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Constantia\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐ明朝\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"궁서\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"仿宋\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"標楷體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Elemental:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGS明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Browallia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Equity:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG創英ﾌﾟﾚｾﾞﾝｽEB\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Aharoni\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"EucrosiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Essential:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"黑体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Executive:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGS明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Browallia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Flow:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGP明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY신명조\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Majalla UI\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"David\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Browallia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Foundry:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG明朝B\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"바탕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正姚体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"標楷體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"David\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"JasmineUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Grid:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG創英角ｺﾞｼｯｸUB\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY견고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial Bold\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial Bold\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial Bold\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Hardcover:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGS明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"David\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"EucrosiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Horizon:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY얕은샘물M\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正姚体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Levenim MT\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Median:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGPｺﾞｼｯｸE\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY얕은샘물M\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文仿宋\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Levenim MT\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Metro:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Miriam\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"DilleniaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Module:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY엽서L\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文楷体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Miriam\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"DilleniaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Newsprint:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐ明朝\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"바탕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Opulent:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG丸ｺﾞｼｯｸM-PRO\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY그래픽M\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文新魏\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Gisha\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"IrisUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Oriel:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐ明朝\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"휴먼매직체\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"KodchiangUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Origin:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文新魏\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Paper:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"궁서\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文新魏\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"標楷體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Browallia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Perspective:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正舒体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Pushpin:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"黑体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Slipstream:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY그래픽M\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正姚体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Gisha\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"IrisUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Solstice:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Corbel\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Corbel\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸE\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY엽서L\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文中宋\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Majalla UI\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Technic:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY중고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"黑体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Levenim MT\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"LilyUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Thatch:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG創英角ｺﾞｼｯｸUB\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY얕은샘물M\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文仿宋\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Levenim MT\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Trek:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸE\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"돋움\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文楷体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Aharoni\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"LilyUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Urban:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG明朝B\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Verve:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY중고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"幼圆\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Gisha\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"DilleniaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            break;
                        case SLThemeTypeValues.Waveform:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGP明朝E\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY그래픽M\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文楷体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"標楷體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"KodchiangUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Autumn:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"굴림\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Decatur:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Kilter:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Cambria\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGS明朝B\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"바탕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"方正姚体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"David\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"JasmineUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Macro:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ 明朝\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Mylar:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HGｺﾞｼｯｸM\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文楷体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Sketchbook:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"HG明朝B\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"黑体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Angsana New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"MoolBoran\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Times New Roman\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Soho:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY견명조\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文楷体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"KodchiangUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Spring:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"굴림\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Summer:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"굴림\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Thermal:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ 明朝\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"宋体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Tradeshow:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"HY견명조\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文楷体\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"KodchiangUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.UrbanPop:
                            sw.Write("<a:font script=\"Grek\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Cyrl\" typeface=\"Calibri\" />");
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ Ｐゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"맑은 고딕\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"华文新魏\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"新細明體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"Cordia New\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Arial\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                        case SLThemeTypeValues.Winter:
                            sw.Write("<a:font script=\"Jpan\" typeface=\"ＭＳ ゴシック\" />");
                            sw.Write("<a:font script=\"Hang\" typeface=\"굴림\" />");
                            sw.Write("<a:font script=\"Hans\" typeface=\"微软雅黑\" />");
                            sw.Write("<a:font script=\"Hant\" typeface=\"微軟正黑體\" />");
                            sw.Write("<a:font script=\"Arab\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Hebr\" typeface=\"Tahoma\" />");
                            sw.Write("<a:font script=\"Thai\" typeface=\"FreesiaUPC\" />");
                            sw.Write("<a:font script=\"Ethi\" typeface=\"Nyala\" />");
                            sw.Write("<a:font script=\"Beng\" typeface=\"Vrinda\" />");
                            sw.Write("<a:font script=\"Gujr\" typeface=\"Shruti\" />");
                            sw.Write("<a:font script=\"Khmr\" typeface=\"DaunPenh\" />");
                            sw.Write("<a:font script=\"Knda\" typeface=\"Tunga\" />");
                            sw.Write("<a:font script=\"Guru\" typeface=\"Raavi\" />");
                            sw.Write("<a:font script=\"Cans\" typeface=\"Euphemia\" />");
                            sw.Write("<a:font script=\"Cher\" typeface=\"Plantagenet Cherokee\" />");
                            sw.Write("<a:font script=\"Yiii\" typeface=\"Microsoft Yi Baiti\" />");
                            sw.Write("<a:font script=\"Tibt\" typeface=\"Microsoft Himalaya\" />");
                            sw.Write("<a:font script=\"Thaa\" typeface=\"MV Boli\" />");
                            sw.Write("<a:font script=\"Deva\" typeface=\"Mangal\" />");
                            sw.Write("<a:font script=\"Telu\" typeface=\"Gautami\" />");
                            sw.Write("<a:font script=\"Taml\" typeface=\"Latha\" />");
                            sw.Write("<a:font script=\"Syrc\" typeface=\"Estrangelo Edessa\" />");
                            sw.Write("<a:font script=\"Orya\" typeface=\"Kalinga\" />");
                            sw.Write("<a:font script=\"Mlym\" typeface=\"Kartika\" />");
                            sw.Write("<a:font script=\"Laoo\" typeface=\"DokChampa\" />");
                            sw.Write("<a:font script=\"Sinh\" typeface=\"Iskoola Pota\" />");
                            sw.Write("<a:font script=\"Mong\" typeface=\"Mongolian Baiti\" />");
                            sw.Write("<a:font script=\"Viet\" typeface=\"Verdana\" />");
                            sw.Write("<a:font script=\"Uigh\" typeface=\"Microsoft Uighur\" />");
                            sw.Write("<a:font script=\"Geor\" typeface=\"Sylfaen\" />");
                            break;
                    }
                    sw.Write("</a:minorFont>");
                    sw.Write("</a:fontScheme>");

                    sw.Write("<a:fmtScheme name=\"{0}\">", SimpleTheme.ThemeName);
                    sw.Write("<a:fillStyleLst>");
                    sw.Write("<a:solidFill>");
                    sw.Write("<a:schemeClr val=\"phClr\" />");
                    sw.Write("</a:solidFill>");
                    sw.Write("<a:gradFill rotWithShape=\"1\">");
                    sw.Write("<a:gsLst>");
                    sw.Write("<a:gs pos=\"0\">");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:tint val=\"50000\" />");
                    sw.Write("<a:satMod val=\"300000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:gs>");
                    sw.Write("<a:gs pos=\"35000\">");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:tint val=\"37000\" />");
                    sw.Write("<a:satMod val=\"300000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:gs>");
                    sw.Write("<a:gs pos=\"100000\">");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:tint val=\"15000\" />");
                    sw.Write("<a:satMod val=\"350000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:gs>");
                    sw.Write("</a:gsLst>");
                    sw.Write("<a:lin ang=\"16200000\" scaled=\"1\" />");
                    sw.Write("</a:gradFill>");
                    sw.Write("<a:gradFill rotWithShape=\"1\">");
                    sw.Write("<a:gsLst>");
                    sw.Write("<a:gs pos=\"0\">");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:shade val=\"51000\" />");
                    sw.Write("<a:satMod val=\"130000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:gs>");
                    sw.Write("<a:gs pos=\"80000\">");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:shade val=\"93000\" />");
                    sw.Write("<a:satMod val=\"130000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:gs>");
                    sw.Write("<a:gs pos=\"100000\">");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:shade val=\"94000\" />");
                    sw.Write("<a:satMod val=\"135000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:gs>");
                    sw.Write("</a:gsLst>");
                    sw.Write("<a:lin ang=\"16200000\" scaled=\"0\" />");
                    sw.Write("</a:gradFill>");
                    sw.Write("</a:fillStyleLst>");
                    sw.Write("<a:lnStyleLst>");
                    sw.Write("<a:ln w=\"9525\" cap=\"flat\" cmpd=\"sng\" algn=\"ctr\">");
                    sw.Write("<a:solidFill>");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:shade val=\"95000\" />");
                    sw.Write("<a:satMod val=\"105000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:solidFill>");
                    sw.Write("<a:prstDash val=\"solid\" />");
                    sw.Write("</a:ln>");
                    sw.Write("<a:ln w=\"25400\" cap=\"flat\" cmpd=\"sng\" algn=\"ctr\">");
                    sw.Write("<a:solidFill>");
                    sw.Write("<a:schemeClr val=\"phClr\" />");
                    sw.Write("</a:solidFill>");
                    sw.Write("<a:prstDash val=\"solid\" />");
                    sw.Write("</a:ln>");
                    sw.Write("<a:ln w=\"38100\" cap=\"flat\" cmpd=\"sng\" algn=\"ctr\">");
                    sw.Write("<a:solidFill>");
                    sw.Write("<a:schemeClr val=\"phClr\" />");
                    sw.Write("</a:solidFill>");
                    sw.Write("<a:prstDash val=\"solid\" />");
                    sw.Write("</a:ln>");
                    sw.Write("</a:lnStyleLst>");
                    sw.Write("<a:effectStyleLst>");
                    sw.Write("<a:effectStyle>");
                    sw.Write("<a:effectLst>");
                    sw.Write("<a:outerShdw blurRad=\"40000\" dist=\"20000\" dir=\"5400000\" rotWithShape=\"0\">");
                    sw.Write("<a:srgbClr val=\"000000\">");
                    sw.Write("<a:alpha val=\"38000\" />");
                    sw.Write("</a:srgbClr>");
                    sw.Write("</a:outerShdw>");
                    sw.Write("</a:effectLst>");
                    sw.Write("</a:effectStyle>");
                    sw.Write("<a:effectStyle>");
                    sw.Write("<a:effectLst>");
                    sw.Write("<a:outerShdw blurRad=\"40000\" dist=\"23000\" dir=\"5400000\" rotWithShape=\"0\">");
                    sw.Write("<a:srgbClr val=\"000000\">");
                    sw.Write("<a:alpha val=\"35000\" />");
                    sw.Write("</a:srgbClr>");
                    sw.Write("</a:outerShdw>");
                    sw.Write("</a:effectLst>");
                    sw.Write("</a:effectStyle>");
                    sw.Write("<a:effectStyle>");
                    sw.Write("<a:effectLst>");
                    sw.Write("<a:outerShdw blurRad=\"40000\" dist=\"23000\" dir=\"5400000\" rotWithShape=\"0\">");
                    sw.Write("<a:srgbClr val=\"000000\">");
                    sw.Write("<a:alpha val=\"35000\" />");
                    sw.Write("</a:srgbClr>");
                    sw.Write("</a:outerShdw>");
                    sw.Write("</a:effectLst>");
                    sw.Write("<a:scene3d>");
                    sw.Write("<a:camera prst=\"orthographicFront\">");
                    sw.Write("<a:rot lat=\"0\" lon=\"0\" rev=\"0\" />");
                    sw.Write("</a:camera>");
                    sw.Write("<a:lightRig rig=\"threePt\" dir=\"t\">");
                    sw.Write("<a:rot lat=\"0\" lon=\"0\" rev=\"1200000\" />");
                    sw.Write("</a:lightRig>");
                    sw.Write("</a:scene3d>");
                    sw.Write("<a:sp3d>");
                    sw.Write("<a:bevelT w=\"63500\" h=\"25400\" />");
                    sw.Write("</a:sp3d>");
                    sw.Write("</a:effectStyle>");
                    sw.Write("</a:effectStyleLst>");
                    sw.Write("<a:bgFillStyleLst>");
                    sw.Write("<a:solidFill>");
                    sw.Write("<a:schemeClr val=\"phClr\" />");
                    sw.Write("</a:solidFill>");
                    sw.Write("<a:gradFill rotWithShape=\"1\">");
                    sw.Write("<a:gsLst>");
                    sw.Write("<a:gs pos=\"0\">");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:tint val=\"40000\" />");
                    sw.Write("<a:satMod val=\"350000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:gs>");
                    sw.Write("<a:gs pos=\"40000\">");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:tint val=\"45000\" />");
                    sw.Write("<a:shade val=\"99000\" />");
                    sw.Write("<a:satMod val=\"350000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:gs>");
                    sw.Write("<a:gs pos=\"100000\">");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:shade val=\"20000\" />");
                    sw.Write("<a:satMod val=\"255000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:gs>");
                    sw.Write("</a:gsLst>");
                    sw.Write("<a:path path=\"circle\">");
                    sw.Write("<a:fillToRect l=\"50000\" t=\"-80000\" r=\"50000\" b=\"180000\" />");
                    sw.Write("</a:path>");
                    sw.Write("</a:gradFill>");
                    sw.Write("<a:gradFill rotWithShape=\"1\">");
                    sw.Write("<a:gsLst>");
                    sw.Write("<a:gs pos=\"0\">");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:tint val=\"80000\" />");
                    sw.Write("<a:satMod val=\"300000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:gs>");
                    sw.Write("<a:gs pos=\"100000\">");
                    sw.Write("<a:schemeClr val=\"phClr\">");
                    sw.Write("<a:shade val=\"30000\" />");
                    sw.Write("<a:satMod val=\"200000\" />");
                    sw.Write("</a:schemeClr>");
                    sw.Write("</a:gs>");
                    sw.Write("</a:gsLst>");
                    sw.Write("<a:path path=\"circle\">");
                    sw.Write("<a:fillToRect l=\"50000\" t=\"50000\" r=\"50000\" b=\"50000\" />");
                    sw.Write("</a:path>");
                    sw.Write("</a:gradFill>");
                    sw.Write("</a:bgFillStyleLst>");
                    sw.Write("</a:fmtScheme>");
                    sw.Write("</a:themeElements>");

                    sw.Write("<a:objectDefaults />");

                    sw.Write("<a:extraClrSchemeLst />");

                    sw.Write("</a:theme>");

                    sw.Flush();

                    ms.Position = 0;
                    themePart.FeedData(ms);
                }
            }
        }
    }
}
